@@ -6,35 +6,27 @@ IPDR - IPDR Data Suite
 
 =head1 VERSION
 
-Version 0.41
+Version 0.15
 
 =cut
 
-our $VERSION = '0.41';
+our $VERSION = '0.15';
 
 =head1 SYNOPSIS
 
 This is a IPDR collection suite for currently Cisco and generic IPDR compliant
 servers.
 
-To use the XDR module to extract XDR files see the man page
-
-IPDR::Process::XDR
-
 To use the Cisco implementation of IPDR (SAMIS) see the man page
 
 IPDR::Collection::Cisco
 
-To use the Cisco Secure implementation of IPDR (SAMIS) see the man page
-
-IPDR::Collection::CiscoSSL
-
 To use the generic client implementation of IPDR see the man page
 
 IPDR::Collection::Client
 
-The generic client has been tested with Motorola and Arris (although very limited
-testing with Arris).
+The generic client has been tested with Motorola and Aris (although very limited
+testing with Aris).
 
 =cut
 
@@ -82,7 +74,7 @@ L<http://search.cpan.org/dist/IPDR>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2011 Andrew S. Kennedy, all rights reserved.
+Copyright 2009 Andrew S. Kennedy, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
